@@ -47,16 +47,16 @@
 // libtdescreensaver interface
 extern "C"
 {
-    KDE_EXPORT const char *kss_applicationName = "kblob.kss";
-    KDE_EXPORT const char *kss_description = I18N_NOOP( "KBlob" );
-    KDE_EXPORT const char *kss_version = "2.2.0";
+    TDE_EXPORT const char *kss_applicationName = "kblob.kss";
+    TDE_EXPORT const char *kss_description = I18N_NOOP( "KBlob" );
+    TDE_EXPORT const char *kss_version = "2.2.0";
 
-    KDE_EXPORT KScreenSaver *kss_create( WId id )
+    TDE_EXPORT KScreenSaver *kss_create( WId id )
     {
         return new KBlobSaver( id );
     }
 
-    KDE_EXPORT TQDialog *kss_setup()
+    TDE_EXPORT TQDialog *kss_setup()
     {
         return new KBlobSetup();
     }
