@@ -6,7 +6,7 @@
 #include <tqvbox.h>
 #include <tdelocale.h>
 
-extern "C" KDE_EXPORT TQObject* allocate_config( TDEConfig* conf, TQWidget* parent )
+extern "C" TDE_EXPORT TQObject* allocate_config( TDEConfig* conf, TQWidget* parent )
 {
 	return new CdeConfig(conf, parent);
 }
