@@ -40,7 +40,7 @@
 
 #include "OpenLook.h"
 
-extern "C" KDE_EXPORT KDecorationFactory* create_factory()
+extern "C" TDE_EXPORT KDecorationFactory* create_factory()
 {
     return new OpenLook::DecorationFactory();
 }
@@ -168,30 +168,30 @@ bool OpenLook::eventFilter(TQObject *o, TQEvent *e)
   if (o != widget()) return false;
   switch (e->type()) {
   case TQEvent::Resize:
-    resizeEvent(TQT_TQRESIZEEVENT(e));
+    resizeEvent(static_cast<TQResizeEvent*>(e));
     return true;
   case TQEvent::Paint:
-    paintEvent(TQT_TQPAINTEVENT(e));
+    paintEvent(static_cast<TQPaintEvent*>(e));
     return true;
   case TQEvent::MouseButtonDblClick:
-    mouseDoubleClickEvent(TQT_TQMOUSEEVENT(e));
+    mouseDoubleClickEvent(static_cast<TQMouseEvent*>(e));
     return true;
   case TQEvent::Wheel:
-    wheelEvent( TQT_TQWHEELEVENT( e ));
+    wheelEvent( static_cast<TQWheelEvent*>( e ));
     return true;
   case TQEvent::MouseButtonPress:
-    if (!isButtonPress(TQT_TQMOUSEEVENT(e))) {
-      processMousePressEvent(TQT_TQMOUSEEVENT(e));
+    if (!isButtonPress(static_cast<TQMouseEvent*>(e))) {
+      processMousePressEvent(static_cast<TQMouseEvent*>(e));
     }
     return true;
   case TQEvent::MouseButtonRelease:
-    if (isButtonRelease(TQT_TQMOUSEEVENT(e))) {
+    if (isButtonRelease(static_cast<TQMouseEvent*>(e))) {
       return true;
     } else {
       return false;
     }
   case TQEvent::Show:
-    showEvent(TQT_TQSHOWEVENT(e));
+    showEvent(static_cast<TQShowEvent*>(e));
     return true;
   default:
     break;
@@ -281,7 +281,7 @@ OpenLook::showEvent(TQShowEvent *)
   void
 OpenLook::mouseDoubleClickEvent(TQMouseEvent * e)
 {
-  if (e->button() == Qt::LeftButton && titleRect().contains(e->pos()))
+  if (e->button() == TQt::LeftButton && titleRect().contains(e->pos()))
   {
 	  titlebarDblClickOperation();
   }
