@@ -732,7 +732,7 @@ TQValueList<KDecorationFactory::BorderSize> SystemDecoFactory::borderSizes() con
 
 }
 
-extern "C" KDE_EXPORT KDecorationFactory *create_factory()
+extern "C" TDE_EXPORT KDecorationFactory *create_factory()
 {
    return new System::SystemDecoFactory();
 }
